@@ -34,15 +34,13 @@ class Client(AbstractAsyncClient):
         :returns: response text
         """
 
-        kwargs = {
-            'headers': {'Content-Type': pjrpc.common.DEFAULT_CONTENT_TYPE},
-            **kwargs,
-        }
+        headers = kwargs.setdefault('headers', {})
+        headers['Content-Type'] = pjrpc.common.DEFAULT_CONTENT_TYPE
 
-        resp = await self._session.post(self._endpoint, data=request_text, **kwargs)
-        resp.raise_for_status()
+        async with self._session.post(self._endpoint, data=request_text, **kwargs) as resp:
+            resp.raise_for_status()
+            response_text = await resp.text()
 
-        response_text = await resp.text()
         if is_notification:
             return None
 
