@@ -1,9 +1,9 @@
 import inspect
-from typing import Any, Dict, Iterable, List, Optional, Type, Union
+from typing import Any, Dict, Iterable, List, Optional, Type
 
 import pydantic as pd
 
-from pjrpc.common import UNSET, UnsetType
+from pjrpc.common import UNSET, MaybeSet
 from pjrpc.common.exceptions import JsonRpcError
 from pjrpc.common.typedefs import MethodType
 from pjrpc.server.specs.extractors import BaseSchemaExtractor, Error, Schema
@@ -33,7 +33,7 @@ class PydanticSchemaExtractor(BaseSchemaExtractor):
                 )
 
         params_model = pd.create_model('RequestModel', **field_definitions)
-        model_schema = params_model.schema(ref_template=self._ref_template)
+        model_schema = params_model.model_json_schema(ref_template=self._ref_template)
 
         parameters_schema = {}
         for param_name, param_schema in model_schema['properties'].items():
@@ -45,7 +45,7 @@ class PydanticSchemaExtractor(BaseSchemaExtractor):
                 description=param_schema.get('description', UNSET),
                 deprecated=param_schema.get('deprecated', UNSET),
                 required=required,
-                definitions=model_schema.get('definitions'),
+                definitions=model_schema.get('$defs'),
             )
 
         return parameters_schema
@@ -60,8 +60,8 @@ class PydanticSchemaExtractor(BaseSchemaExtractor):
         else:
             return_annotation = result.return_annotation
 
-        result_model = pd.create_model('ResultModel', result=(return_annotation, pd.fields.Undefined))
-        model_schema = result_model.schema(ref_template=self._ref_template)
+        result_model = pd.create_model('ResultModel', result=(return_annotation, ...))
+        model_schema = result_model.model_json_schema(ref_template=self._ref_template)
 
         result_schema = model_schema['properties']['result']
         required = 'result' in model_schema.get('required', [])
@@ -74,7 +74,7 @@ class PydanticSchemaExtractor(BaseSchemaExtractor):
             description=result_schema.get('description', UNSET),
             deprecated=result_schema.get('deprecated', UNSET),
             required=required,
-            definitions=model_schema.get('definitions', UNSET),
+            definitions=model_schema.get('$defs', UNSET),
         )
 
         return result_schema
@@ -83,7 +83,7 @@ class PydanticSchemaExtractor(BaseSchemaExtractor):
         self,
         method: MethodType,
         errors: Optional[Iterable[Type[JsonRpcError]]] = None,
-    ) -> Union[UnsetType, List[Error]]:
+    ) -> MaybeSet[List[Error]]:
         if errors:
             errors_schema = []
             for error in errors:
@@ -95,7 +95,7 @@ class PydanticSchemaExtractor(BaseSchemaExtractor):
                     field_definitions[field_name] = (annotation, getattr(error, field_name, ...))
 
                 result_model = pd.create_model(error.message, **field_definitions)
-                model_schema = result_model.schema(ref_template=self._ref_template)
+                model_schema = result_model.model_json_schema(ref_template=self._ref_template)
 
                 data_schema = model_schema['properties'].get('data', UNSET)
                 required = 'data' in model_schema.get('required', [])
@@ -109,7 +109,7 @@ class PydanticSchemaExtractor(BaseSchemaExtractor):
                         title=error.message,
                         description=inspect.cleandoc(error.__doc__) if error.__doc__ is not None else UNSET,
                         deprecated=model_schema.get('deprecated', UNSET),
-                        definitions=model_schema.get('definitions'),
+                        definitions=model_schema.get('$defs'),
                     ),
                 )
             return errors_schema
@@ -126,7 +126,7 @@ class PydanticSchemaExtractor(BaseSchemaExtractor):
         return field_schema
 
     @staticmethod
-    def _get_annotations(cls: Type) -> Dict[str, Any]:
+    def _get_annotations(cls: Type[Any]) -> Dict[str, Any]:
         annotations: Dict[str, Any] = {}
         for patent in cls.mro():
             annotations.update(**getattr(patent, '__annotations__', {}))
